# wwu_tinker
wwu-tinker is an API webservice for hyperparamenter optimization.
This free machine learning web service in Python with extensible APIs that researcher can use to tune hyperparameter configuraions.

A simple analogy on hyperparameter tuning.  Imagine a recording studio with a sound booth that has devices with dozens of knobs.  
The musicians create the music (the parameters), the sound technician adjusts the knobs on the soundboard (the hyperparameters), the output is the quality of music (the cost function).
wwu-tinker is your sound technician of your machine learning projects who adjusts the soundboard to produce quality music. 

## Where to get it

Python installer:

`pip install wwu_tinker`

## Functionality
Check out the [wwu-tinker wiki](https://github.com/hutchresearch/wwu_tinker/wiki) for detailed instructions on using our API.

* Setup an Experiment
* Add variables to an experiment
* Submitting an experiment
* Requesting experiment evaluations from server
* Additional experiment tools

In-depth walkthrough.

## Examples

Iris example

## Project Info

pypi: [wwu-tinker](https://pypi.python.org/pypi/wwu-tinker)

The source code for the API client application is hosted on [GitHub](https://github.com/hutchresearch/wwu_tinker).

&copy; 2017-2018 Hutch Research - Western Washington University Dept. of Computer Science